@@ -2,7 +2,7 @@ package DBIx::QuickDB;
 use strict;
 use warnings;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 use Carp;
 use List::Util qw/first/;
@@ -67,23 +67,22 @@ sub build_db {
         confess join "\n" => @err, "", "====================", "", "Aborting";
     }
 
-    my $inst = $driver->new(
-        dir       => $spec->{dir},
-        cleanup   => $spec->{cleanup},
-        autostart => $spec->{autostart},
-        autostop  => $spec->{autostop},
-        verbose   => $spec->{verbose},
-    );
+    my $inst = $driver->new(%$spec);
 
     $CACHE{$name} = {spec => $spec, inst => $inst} if $name && !$spec->{nocache};
 
     $inst->bootstrap if $spec->{bootstrap};
     $inst->start     if $spec->{autostart};
 
+    # load_sql => {
+    #   postgresql => [db => $file, $db => $file],
+    # }
     if (my $sql = $spec->{load_sql}) {
         $sql = $sql->{$driver} if ref($sql) eq 'HASH';
-        $sql = [$sql] unless ref $sql;
-        $inst->load_sql($_) for @$sql;
+        for (my $i = 0; $i < @$sql; $i += 2) {
+            my ($db, $file) = @{$sql}[$i, $i + 1];
+            $inst->load_sql($db => $file);
+        }
     }
 
     return $inst;
